==> jwtson-1.0.1.tar.gz: lib/jwtson_method_channel.dart <==
import 'dart:convert';

import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';

import 'jwtson_platform_interface.dart';
/*
 * Dayona
 * Created on Thu Jun 02 2022
 * email : dayonaart@gmail.com
 * Copyright (c) 2022
 */

/// An implementation of [JwtsonPlatform] that uses method channels.
class MethodChannelJwtson extends JwtsonPlatform {
  /// The method channel used to interact with the native platform.
  @visibleForTesting
  final methodChannel = const MethodChannel('jwtson');

  @override
  Future<String?> generateToken(String? key, String? data) async {
    final result = await methodChannel
        .invokeMethod<String>('generatePayload', <String, dynamic>{'key': key, 'data': data});
    try {
      return result;
    } catch (e) {
      return null;
    }
  }

  @override
  Future<PayloadResult?> decodeJwtToken(String? key, String? data) async {
    final result = await methodChannel
        .invokeMethod<dynamic>('decodeJWT', <String, dynamic>{'key': key, 'data': data});
    try {
      return PayloadResult.fromJson(Map<String, dynamic>.from(result!));
    } catch (e) {
      // print(e);
      return null;
    }
  }
}

class PayloadResult {
  dynamic data;
  // var expired;

  PayloadResult({
    this.data,
    // this.expired,
  });

  factory PayloadResult.fromJson(Map<String, dynamic> json) => PayloadResult(
        data: json['data'],
        // expired: json['date'],
      );

  Map<String, dynamic> toJson() => {
        'data': data,
        // 'expired': expired,
      };
}

==> jwtson-1.0.3.tar.gz: lib/jwtson_method_channel.dart <==
import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';
import 'jwtson_platform_interface.dart';
/*
 * Dayona
 * Created on Thu Jun 02 2022
 * email : dayonaart@gmail.com
 * Copyright (c) 2022
 */

/// An implementation of [JwtsonPlatform] that uses method channels.
class MethodChannelJwtson extends JwtsonPlatform {
  /// The method channel used to interact with the native platform.
  @visibleForTesting
  final methodChannel = const MethodChannel('jwtson');

  @override
  Future<String?> generateToken(String? key, String? data) async {
    final result = await methodChannel
        .invokeMethod<String>('generatePayload', <String, dynamic>{'key': key, 'data': data});
    try {
      return result;
    } catch (e) {
      return null;
    }
  }

  @override
  Future<PayloadResult?> decodeJwtToken(String? key, String? data) async {
    final result = await methodChannel
        .invokeMethod<dynamic>('decodeJWT', <String, dynamic>{'key': key, 'data': data});
    try {
      final data = PayloadResult.fromJson(Map<String, dynamic>.from(result!));
      if (data.expired) {
        return PayloadResult(data: "token expired");
      } else {
        return data;
      }
    } catch (e) {
      return PayloadResult(data: "$e");
    }
  }
}

class PayloadResult {
  dynamic data;
  bool expired;
  dynamic header;
  PayloadResult({
    this.data,
    this.expired = false,
    this.header,
  });

  factory PayloadResult.fromJson(Map<String, dynamic> json) => PayloadResult(
      data: json['data'],
      expired: DateTime.now().add(Duration(milliseconds: json['exp'])).isBefore(DateTime.now()),
      header: json['haeder']);

  Map<String, dynamic> toJson() => {
        'data': data,
        'expired': expired,
        'header': header,
      };
}
